GridMap

Struct GridMap 

pub struct GridMap<T> { /* private fields */ }
A two-dimensional grid map.

Implementations

Source

impl<T> GridMap<T>

Properties

pub const fn dims(&self) -> Dim

Gets the dimensions.

Source

impl<T> GridMap<T>

Access

pub fn get(&self, loc: Loc) -> &T

Gets the cell at the location

pub fn get_mut(&mut self, loc: Loc) -> &mut T

Gets the mutable cell at the location

pub fn set(&mut self, loc: Loc, cell: T)

Sets the cell at the location

Source

impl<T> GridMap<T>

Construction

pub fn new<F>(dims: Dim, cell_fn: F) -> Self
where F: Fn(Loc) -> T,

Creates a new grid map with the cell_fn.

Source

impl<T: Clone> GridMap<T>

Construction: Clone

pub fn new_clone(dims: Dim, cell: T) -> Self

Creates a new grid map with the cloned cell.

Source

impl<T: Default> GridMap<T>

Construction: Default

pub fn new_default(dims: Dim) -> Self

Creates a new grid map with the default cell.